Gallery of Examples
===================

This gallery shows usage examples for Chiaro.

Each example contains:

- The Python code
- The resulting interactive plots

.. raw:: html

   <div class="gallery-item">
     <a href="dummy1.html">
       <img src="../_static/gallery/thumbs/dummy1.png" alt="This example shows how to create a scatter plot using Bokeh and export as PNG." />
       <div class="caption">This example shows how to create a scatter plot using Bokeh and export as PNG.</div>
     </a>
   </div>
   <div class="gallery-item">
     <a href="dummy2.html">
       <img src="../_static/gallery/thumbs/dummy2.png" alt="This example shows how to create a bar plot using Bokeh and export as PNG." />
       <div class="caption">This example shows how to create a bar plot using Bokeh and export as PNG.</div>
     </a>
   </div>
   

.. toctree::
   :maxdepth: 1
   :hidden:

   dummy1
   dummy2
